==> qbs-src-1.8.0.zip: qbs-src-1.8.0/src/lib/corelib/language/itempool.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QBS_ITEMPOOL_H
#define QBS_ITEMPOOL_H

#include <parser/qmljsmemorypool_p.h>

#include <QtCore/qlist.h>

namespace qbs {
namespace Internal {

class Item;
enum class ItemType;

class ItemPool
{
    Q_DISABLE_COPY(ItemPool)
public:
    ItemPool();
    ~ItemPool();

    Item *allocateItem(const ItemType &type);

private:
    QbsQmlJS::MemoryPool m_pool;
    typedef QList<Item *> ItemVector;
    ItemVector m_items;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_ITEMPOOL_H

==> qbs-src-1.24.1.zip: qbs-src-1.24.1/src/lib/corelib/language/itempool.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QBS_ITEMPOOL_H
#define QBS_ITEMPOOL_H

#include <parser/qmljsmemorypool_p.h>
#include <tools/qbs_export.h>

#include <vector>

namespace qbs {
namespace Internal {

class Item;
enum class ItemType;

class QBS_AUTOTEST_EXPORT ItemPool
{
    Q_DISABLE_COPY(ItemPool)
public:
    ItemPool();
    ~ItemPool();

    Item *allocateItem(const ItemType &type);

private:
    QbsQmlJS::MemoryPool m_pool;
    std::vector<Item *> m_items;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_ITEMPOOL_H
